@@ -19,7 +19,8 @@ BUNDLED_DATA_DIRECTORY = os.path.join(str(Path(os.path.dirname(__file__))), "dat
 
 LOCAL_HTML_DIRECTORY_PATH = os.path.join(CONFIG_DIRECTORY, "data", "docs")
 
-BASE_DOCUMENTATION_URL = "https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_actions-resources-contextkeys.html"
+BASE_DOCUMENTATION_URL = "https://docs.aws.amazon.com/service-authorization/latest/reference/reference_policies_actions-resources-contextkeys.html"
+# BASE_DOCUMENTATION_URL = "https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_actions-resources-contextkeys.html"
 
 # Data json file
 # On initialization, load the IAM data
@@ -30,9 +31,8 @@ LOCAL_DATASTORE_FILE_PATH = os.path.join(CONFIG_DIRECTORY, "iam-definition.json"
 # Check for the existence of the local datastore first.
 if os.path.exists(LOCAL_DATASTORE_FILE_PATH):
     # If it exists, leverage that datastore instead of the one bundled with the python package
-    logger.info(f"The IAM definition at {LOCAL_DATASTORE_FILE_PATH} exists. "
-                f"Leveraging that IAM definition instead of the definition bundled with the python package. "
-                f"To leverage the bundled definition, remove the folder $HOME/.policy_sentry/")
+    logger.info(f"Leveraging the local IAM definition at the path: {LOCAL_DATASTORE_FILE_PATH} "
+                f"To leverage the bundled definition instead, remove the folder $HOME/.policy_sentry/")
     DATASTORE_FILE_PATH = LOCAL_DATASTORE_FILE_PATH
 else:
     # Otherwise, leverage the datastore inside the python package
